Crate arora_types

Crate arora_types 

Re-exports

pub use arora_type::AroraType;

Modules

arora_type
A Rust type that describes itself as an arora low::Type.
call
data
The Arora data interface.
keyvalue
module
record
Type records: versioned type specifications and the machinery to pin them.
ty
value
value_serde
(De)serialization to and from arora’s Value, in two layers:

Structs

SemanticVersion
Uuid
A Universally Unique Identifier (UUID).

Functions

gen_bb_uuid
gen_uuid_from_str

Derive Macros

AroraType