Re-exports
pub use arora_type::AroraType;
Modules
- arora_
type - A Rust type that describes itself as an arora
low::Type. - call
- data
- The Arora data interface.
- keyvalue
- module
- record
- Type records: versioned type specifications and the machinery to pin them.
- ty
- value
- value_
serde - (De)serialization to and from arora’s
Value, in two layers:
Structs
- Semantic
Version - Uuid
- A Universally Unique Identifier (UUID).