pub struct Call {
pub module_id: Option<Uuid>,
pub id: Uuid,
pub args: Vec<StructureField>,
}Expand description
A call is described like a structure in arora engine.
Fields
module_id: Option<Uuid>The ID of the module where to find the function ID. If absent, look for it locally.
id: UuidThe function ID to call.
args: Vec<StructureField>Arguments to call the functions with.